export interface InputProps<A> {
    onChange: (v: A | undefined) => void;
    value?: A;
    errors?: string[];
    disabled?: boolean;
    placeholder?: string;
}
export interface OptionSet<A> {
    id: A;
    name: string;
}
/**
 * select props for dropdowns that return either a string or number (ie. enum)
 */
export declare type InputTypeString = "text" | "email" | "password";
/**
 * select props for dropdowns that return an option set
 */
export declare type InputType = InputTypeString | "number";
export interface SelectProps<A> extends InputProps<A> {
    options: OptionSet<A>[];
}
export interface SelectOptionSetProps<A> extends InputProps<OptionSet<A>> {
    options: OptionSet<A>[];
}
export declare type TypeUnit = "string" | "number" | "category";
export interface StructureUnit<A> {
    name: keyof A;
    label: string;
    type?: TypeUnit;
    options?: {
        id: number;
        name: string;
    }[];
}
export interface FormProps<A> {
    data: Partial<A>;
    structure: StructureUnit<A>[];
    errors?: {
        [k in keyof A]?: string[];
    };
    onSubmit: (data: Partial<A>) => Promise<void>;
}
export declare type ToggleProps<A> = FormProps<A>;
